==> cdk-runtime-values-0.10.0-sources.jar: software/amazon/awscdk/runtimevalues/RuntimeValue.java <==
package software.amazon.awscdk.runtimevalues;

/**
 * Defines a value published from construction code which needs to be accessible
 * by runtime code.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:48:22.200Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.runtimevalues.$Module.class, fqn = "@aws-cdk/runtime-values.RuntimeValue")
public class RuntimeValue extends software.amazon.awscdk.Construct {
    protected RuntimeValue(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        ENV_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.runtimevalues.RuntimeValue.class, "ENV_NAME", java.lang.String.class);
        ENV_VALUE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.runtimevalues.RuntimeValue.class, "ENV_VALUE", software.amazon.awscdk.AwsStackName.class);
    }
    public RuntimeValue(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.runtimevalues.RuntimeValueProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    /**
     * Grants a principal read permissions on this runtime value.
     * @param principal The principal (e.g. Role, User, Group)
     */
    public void grantRead(@javax.annotation.Nullable final software.amazon.awscdk.services.iam.IIdentityResource principal) {
        this.jsiiCall("grantRead", Void.class, java.util.stream.Stream.of(principal).toArray());
    }

    /**
     * Grants a principal read permissions on this runtime value.
     */
    public void grantRead() {
        this.jsiiCall("grantRead", Void.class);
    }
    /**
     * The recommended name of the environment variable to use to set the stack name
     * from which the runtime value is published.
     */
    public final static java.lang.String ENV_NAME;
    /**
     * The value to assign to the `RTV_STACK_NAME` environment variable.
     */
    public final static software.amazon.awscdk.AwsStackName ENV_VALUE;

    /**
     * The ARN fo the SSM parameter used for this runtime value.
     */
    public java.lang.String getParameterArn() {
        return this.jsiiGet("parameterArn", java.lang.String.class);
    }

    /**
     * The name of the runtime parameter.
     */
    public java.lang.String getParameterName() {
        return this.jsiiGet("parameterName", java.lang.String.class);
    }
}

==> cdk-runtime-values-0.26.0-sources.jar: software/amazon/awscdk/runtimevalues/RuntimeValue.java <==
package software.amazon.awscdk.runtimevalues;

/**
 * Defines a value published from construction code which needs to be accessible
 * by runtime code.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T13:00:41.525Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.runtimevalues.$Module.class, fqn = "@aws-cdk/runtime-values.RuntimeValue")
public class RuntimeValue extends software.amazon.awscdk.Construct {
    protected RuntimeValue(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        ENV_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.runtimevalues.RuntimeValue.class, "ENV_NAME", java.lang.String.class);
    }
    public RuntimeValue(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.runtimevalues.RuntimeValueProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    /**
     * Grants a principal read permissions on this runtime value.
     * @param principal The principal (e.g. Role, User, Group)
     */
    public void grantRead(@javax.annotation.Nullable final software.amazon.awscdk.services.iam.IPrincipal principal) {
        this.jsiiCall("grantRead", Void.class, java.util.stream.Stream.of(principal).toArray());
    }

    /**
     * Grants a principal read permissions on this runtime value.
     */
    public void grantRead() {
        this.jsiiCall("grantRead", Void.class);
    }
    /**
     * The recommended name of the environment variable to use to set the stack name
     * from which the runtime value is published.
     */
    public final static java.lang.String ENV_NAME;

    /**
     * The value to assign to the `RTV_STACK_NAME` environment variable.
     */
    public java.lang.String getEnvValue() {
        return this.jsiiGet("envValue", java.lang.String.class);
    }

    /**
     * The ARN fo the SSM parameter used for this runtime value.
     */
    public java.lang.String getParameterArn() {
        return this.jsiiGet("parameterArn", java.lang.String.class);
    }

    /**
     * The name of the runtime parameter.
     */
    public java.lang.String getParameterName() {
        return this.jsiiGet("parameterName", java.lang.String.class);
    }
}
